==> prpc-0.1.33.tgz: package/client/request.js <==
function execute (options,data,urlArgs,cb){
    var noptions;
    var isSec;
    if(typeof options=="string"){
        //此处是为下面的redirect准备的;
        noptions=options;
        isSec=options.startsWith("https")
    }else{
        noptions=Object.assign({},options)
        isSec=noptions.sec;
    }
    //var sendData;
    if(Array.isArray(urlArgs)){
        var path=noptions.path;
        urlArgs.forEach((value,index)=>{
            var re = new RegExp("\\{" + index + "\\}", "gm");
            path = path.replace(re, value);
        })
        noptions.path=path;
    }
    if (noptions.method == "GET"&&data) {
        if (noptions.path.indexOf("?") >= 0) {
            noptions.path = noptions.path + "&" + data;
        } else {
            noptions.path = noptions.path + "?" + data;
        }
        data = undefined;
    }
    var lastParameter=arguments[arguments.length-1];
    if(typeof lastParameter=="function"){
        cb=lastParameter;
    }
    var http=isSec?require("https"):require("http")
    const req = http.request(noptions, (res) => {
        var buffer;
        res.on('data', (chunk) => {
            if(!buffer){
                buffer=chunk;
            }else{
                buffer=Buffer.concat([buffer,chunk])
            }
        });
        res.on('end', () => {
            var resType=noptions.dataType||res.headers["content-type"]||"json";
            var result;
            if(resType.indexOf("json")!=-1){
                result=JSON.parse(buffer.toString());
            }else if(resType.indexOf("text")!=-1){
                result=buffer.toString();
            }else if (resType.indexOf("Buffer")!=-1){
                result={c:buffer.readUInt8(0),o:buffer.subarray(1)}
            }else{
                result=buffer;
            }
            if(res.statusCode==302){
                result=res.headers["location"];
                if(noptions.redirect){
                    execute(result).then(function(result){
                        if(cb){
                            cb(null,result);
                        }else{
                            accept(result)
                        }  
                    }).catch(reject)
                    return;
                }
            }else if(res.statusCode!=200){
                reject(new Error(`call ${noptions.path} result:${res.statusCode} with body=${buffer.toString()}`));
                return;
            }
            if(cb){
                cb(null,result);
            }else{
                accept(result)
            }            
        });
    });

    // write data to request body
    var accept,reject=cb;
    req.end(data);
    var promise;
    if(!cb){
        promise=new Promise((a,r)=>{accept=a,reject=r});
    }
    req.on('error', reject);
    req.on('timeout', reject);
    return promise;//如果有回调函 return 值没有意义,所以可以返回undefined;
}
module.exports=execute

==> prpc-0.1.35.tgz: package/client/request.js <==
function execute (options,data,urlArgs,cb){
    var noptions;
    var isSec;
    if(typeof options=="string"){
        //此处是为下面的redirect准备的;
        noptions=options;
        isSec=options.startsWith("https")
    }else{
        noptions=Object.assign({},options)
        isSec=noptions.sec;
    }
    //var sendData;
    if(Array.isArray(urlArgs)){
        var path=noptions.path;
        urlArgs.forEach((value,index)=>{
            var re = new RegExp("\\{" + index + "\\}", "gm");
            path = path.replace(re, value);
        })
        noptions.path=path;
    }
    if (noptions.method == "GET"&&data) {
        if (noptions.path.indexOf("?") >= 0) {
            noptions.path = noptions.path + "&" + data;
        } else {
            noptions.path = noptions.path + "?" + data;
        }
        data = undefined;
    }
    var lastParameter=arguments[arguments.length-1];
    if(typeof lastParameter=="function"){
        cb=lastParameter;
    }
    var http=isSec?require("https"):require("http")
    const req = http.request(noptions, (res) => {
        var buffer;
        res.on('data', (chunk) => {
            if(!buffer){
                buffer=chunk;
            }else{
                buffer=Buffer.concat([buffer,chunk])
            }
        });
        res.on('end', () => {
            var resType=noptions.dataType||res.headers["content-type"]||"json";
            var result;
            if(resType.indexOf("json")!=-1){
                result=JSON.parse(buffer.toString());
            }else if(resType.indexOf("text")!=-1){
                result=buffer.toString();
            }else if (resType.indexOf("Buffer")!=-1){
                result={c:buffer.readUInt8(0),o:buffer.subarray(1)}
            }else{
                result=buffer;
            }
            if(res.statusCode==302){
                result=res.headers["location"];
                if(noptions.redirect){
                    execute(result).then(function(result){
                        if(cb){
                            cb(null,result);
                        }else{
                            accept(result)
                        }  
                    }).catch(reject)
                    return;
                }
            }else if(res.statusCode!=200){
                reject(new Error(`call ${noptions.path} result:${res.statusCode} with body=${buffer.toString()}`));
                return;
            }
            if(cb){
                cb(null,result);
            }else{
                accept(result)
            }            
        });
    });

    // write data to request body
    var accept,reject=cb;
    req.end(data);
    var promise;
    if(!cb){
        promise=new Promise((a,r)=>{accept=a,reject=r});
    }
    req.on('error', reject);
    req.on('timeout', ()=>{req.abort();});
    return promise;//如果有回调函 return 值没有意义,所以可以返回undefined;
}
module.exports=execute
